# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ManagedClusterArgs', 'ManagedCluster']

@pulumi.input_type
class ManagedClusterArgs:
    def __init__(__self__, *,
                 client_connection_port: pulumi.Input[int],
                 http_gateway_port: pulumi.Input[int],
                 lb_rules: pulumi.Input[Sequence[pulumi.Input['ManagedClusterLbRuleArgs']]],
                 resource_group_name: pulumi.Input[str],
                 authentication: Optional[pulumi.Input['ManagedClusterAuthenticationArgs']] = None,
                 backup_service_enabled: Optional[pulumi.Input[bool]] = None,
                 custom_fabric_settings: Optional[pulumi.Input[Sequence[pulumi.Input['ManagedClusterCustomFabricSettingArgs']]]] = None,
                 dns_name: Optional[pulumi.Input[str]] = None,
                 dns_service_enabled: Optional[pulumi.Input[bool]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 node_types: Optional[pulumi.Input[Sequence[pulumi.Input['ManagedClusterNodeTypeArgs']]]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 sku: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 upgrade_wave: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ManagedCluster resource.
        :param pulumi.Input[int] client_connection_port: Port to use when connecting to the cluster.
        :param pulumi.Input[int] http_gateway_port: Port that should be used by the Service Fabric Explorer to visualize applications and cluster status.
        :param pulumi.Input[Sequence[pulumi.Input['ManagedClusterLbRuleArgs']]] lb_rules: One or more `lb_rule` blocks as defined below.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Resource Group should exist. Changing this forces a new Resource Group to be created.
        :param pulumi.Input['ManagedClusterAuthenticationArgs'] authentication: Controls how connections to the cluster are authenticated. A `authentication` block as defined below.
        :param pulumi.Input[bool] backup_service_enabled: If true, backup service is enabled.
        :param pulumi.Input[Sequence[pulumi.Input['ManagedClusterCustomFabricSettingArgs']]] custom_fabric_settings: One or more `custom_fabric_setting` blocks as defined below.
        :param pulumi.Input[str] dns_name: Hostname for the cluster. If unset the cluster's name will be used..
        :param pulumi.Input[bool] dns_service_enabled: If true, DNS service is enabled.
        :param pulumi.Input[str] location: The Azure Region where the Resource Group should exist. Changing this forces a new Resource Group to be created.
        :param pulumi.Input[str] name: The name which should be used for this Resource Group. Changing this forces a new Resource Group to be created.
        :param pulumi.Input[Sequence[pulumi.Input['ManagedClusterNodeTypeArgs']]] node_types: One or more `node_type` blocks as defined below.
        :param pulumi.Input[str] password: Administrator password for the VMs that will be created as part of this cluster.
        :param pulumi.Input[str] sku: SKU for this cluster. Changing this forces a new resource to be created. Default is `Basic`, allowed values are either `Basic` or `Standard`.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags which should be assigned to the Resource Group.
        :param pulumi.Input[str] upgrade_wave: Upgrade wave for the fabric runtime. Default is `Wave0`, allowed value must be one of `Wave0`, `Wave1`, or `Wave2`.
        :param pulumi.Input[str] username: Administrator password for the VMs that will be created as part of this cluster.
        """
        pulumi.set(__self__, "client_connection_port", client_connection_port)
        pulumi.set(__self__, "http_gateway_port", http_gateway_port)
        pulumi.set(__self__, "lb_rules", lb_rules)
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if authentication is not None:
            pulumi.set(__self__, "authentication", authentication)
        if backup_service_enabled is not None:
            pulumi.set(__self__, "backup_service_enabled", backup_service_enabled)
        if custom_fabric_settings is not None:
            pulumi.set(__self__, "custom_fabric_settings", custom_fabric_settings)
        if dns_name is not None:
            pulumi.set(__self__, "dns_name", dns_name)
        if dns_service_enabled is not None:
            pulumi.set(__self__, "dns_service_enabled", dns_service_enabled)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_types is not None:
            pulumi.set(__self__, "node_types", node_types)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if sku is not None:
            pulumi.set(__self__, "sku", sku)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if upgrade_wave is not None:
            pulumi.set(__self__, "upgrade_wave", upgrade_wave)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter(name="clientConnectionPort")
    def client_connection_port(self) -> pulumi.Input[int]:
        """
        Port to use when connecting to the cluster.
        """
        return pulumi.get(self, "client_connection_port")

    @client_connection_port.setter
    def client_connection_port(self, value: pulumi.Input[int]):
        pulumi.set(self, "client_connection_port", value)

    @property
    @pulumi.getter(name="httpGatewayPort")
    def http_gateway_port(self) -> pulumi.Input[int]:
        """
        Port that should be used by the Service Fabric Explorer to visualize applications and cluster status.
        """
        return pulumi.get(self, "http_gateway_port")

    @http_gateway_port.setter
    def http_gateway_port(self, value: pulumi.Input[int]):
        pulumi.set(self, "http_gateway_port", value)

    @property
    @pulumi.getter(name="lbRules")
    def lb_rules(self) -> pulumi.Input[Sequence[pulumi.Input['ManagedClusterLbRuleArgs']]]:
        """
        One or more `lb_rule` blocks as defined below.
        """
        return pulumi.get(self, "lb_rules")

    @lb_rules.setter
    def lb_rules(self, value: pulumi.Input[Sequence[pulumi.Input['ManagedClusterLbRuleArgs']]]):
        pulumi.set(self, "lb_rules", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[str]:
        """
        The name of the Resource Group where the Resource Group should exist. Changing this forces a new Resource Group to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter
    def authentication(self) -> Optional[pulumi.Input['ManagedClusterAuthenticationArgs']]:
        """
        Controls how connections to the cluster are authenticated. A `authentication` block as defined below.
        """
        return pulumi.get(self, "authentication")

    @authentication.setter
    def authentication(self, value: Optional[pulumi.Input['ManagedClusterAuthenticationArgs']]):
        pulumi.set(self, "authentication", value)

    @property
    @pulumi.getter(name="backupServiceEnabled")
    def backup_service_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, backup service is enabled.
        """
        return pulumi.get(self, "backup_service_enabled")

    @backup_service_enabled.setter
    def backup_service_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "backup_service_enabled", value)

    @property
    @pulumi.getter(name="customFabricSettings")
    def custom_fabric_settings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ManagedClusterCustomFabricSettingArgs']]]]:
        """
        One or more `custom_fabric_setting` blocks as defined below.
        """
        return pulumi.get(self, "custom_fabric_settings")

    @custom_fabric_settings.setter
    def custom_fabric_settings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ManagedClusterCustomFabricSettingArgs']]]]):
        pulumi.set(self, "custom_fabric_settings", value)

    @property
    @pulumi.getter(name="dnsName")
    def dns_name(self) -> Optional[pulumi.Input[str]]:
        """
        Hostname for the cluster. If unset the cluster's name will be used..
        """
        return pulumi.get(self, "dns_name")

    @dns_name.setter
    def dns_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dns_name", value)

    @property
    @pulumi.getter(name="dnsServiceEnabled")
    def dns_service_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, DNS service is enabled.
        """
        return pulumi.get(self, "dns_service_enabled")

    @dns_service_enabled.setter
    def dns_service_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dns_service_enabled", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        The Azure Region where the Resource Group should exist. Changing this forces a new Resource Group to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this Resource Group. Changing this forces a new Resource Group to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="nodeTypes")
    def node_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ManagedClusterNodeTypeArgs']]]]:
        """
        One or more `node_type` blocks as defined below.
        """
        return pulumi.get(self, "node_types")

    @node_types.setter
    def node_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ManagedClusterNodeTypeArgs']]]]):
        pulumi.set(self, "node_types", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        Administrator password for the VMs that will be created as part of this cluster.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter
    def sku(self) -> Optional[pulumi.Input[str]]:
        """
        SKU for this cluster. Changing this forces a new resource to be created. Default is `Basic`, allowed values are either `Basic` or `Standard`.
        """
        return pulumi.get(self, "sku")

    @sku.setter
    def sku(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sku", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags which should be assigned to the Resource Group.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="upgradeWave")
    def upgrade_wave(self) -> Optional[pulumi.Input[str]]:
        """
        Upgrade wave for the fabric runtime. Default is `Wave0`, allowed value must be one of `Wave0`, `Wave1`, or `Wave2`.
        """
        return pulumi.get(self, "upgrade_wave")

    @upgrade_wave.setter
    def upgrade_wave(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "upgrade_wave", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[str]]:
        """
        Administrator password for the VMs that will be created as part of this cluster.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username", value)


@pulumi.input_type
class _ManagedClusterState:
    def __init__(__self__, *,
                 authentication: Optional[pulumi.Input['ManagedClusterAuthenticationArgs']] = None,
                 backup_service_enabled: Optional[pulumi.Input[bool]] = None,
                 client_connection_port: Optional[pulumi.Input[int]] = None,
                 custom_fabric_settings: Optional[pulumi.Input[Sequence[pulumi.Input['ManagedClusterCustomFabricSettingArgs']]]] = None,
                 dns_name: Optional[pulumi.Input[str]] = None,
                 dns_service_enabled: Optional[pulumi.Input[bool]] = None,
                 http_gateway_port: Optional[pulumi.Input[int]] = None,
                 lb_rules: Optional[pulumi.Input[Sequence[pulumi.Input['ManagedClusterLbRuleArgs']]]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 node_types: Optional[pulumi.Input[Sequence[pulumi.Input['ManagedClusterNodeTypeArgs']]]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 sku: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 upgrade_wave: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ManagedCluster resources.
        :param pulumi.Input['ManagedClusterAuthenticationArgs'] authentication: Controls how connections to the cluster are authenticated. A `authentication` block as defined below.
        :param pulumi.Input[bool] backup_service_enabled: If true, backup service is enabled.
        :param pulumi.Input[int] client_connection_port: Port to use when connecting to the cluster.
        :param pulumi.Input[Sequence[pulumi.Input['ManagedClusterCustomFabricSettingArgs']]] custom_fabric_settings: One or more `custom_fabric_setting` blocks as defined below.
        :param pulumi.Input[str] dns_name: Hostname for the cluster. If unset the cluster's name will be used..
        :param pulumi.Input[bool] dns_service_enabled: If true, DNS service is enabled.
        :param pulumi.Input[int] http_gateway_port: Port that should be used by the Service Fabric Explorer to visualize applications and cluster status.
        :param pulumi.Input[Sequence[pulumi.Input['ManagedClusterLbRuleArgs']]] lb_rules: One or more `lb_rule` blocks as defined below.
        :param pulumi.Input[str] location: The Azure Region where the Resource Group should exist. Changing this forces a new Resource Group to be created.
        :param pulumi.Input[str] name: The name which should be used for this Resource Group. Changing this forces a new Resource Group to be created.
        :param pulumi.Input[Sequence[pulumi.Input['ManagedClusterNodeTypeArgs']]] node_types: One or more `node_type` blocks as defined below.
        :param pulumi.Input[str] password: Administrator password for the VMs that will be created as part of this cluster.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Resource Group should exist. Changing this forces a new Resource Group to be created.
        :param pulumi.Input[str] sku: SKU for this cluster. Changing this forces a new resource to be created. Default is `Basic`, allowed values are either `Basic` or `Standard`.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags which should be assigned to the Resource Group.
        :param pulumi.Input[str] upgrade_wave: Upgrade wave for the fabric runtime. Default is `Wave0`, allowed value must be one of `Wave0`, `Wave1`, or `Wave2`.
        :param pulumi.Input[str] username: Administrator password for the VMs that will be created as part of this cluster.
        """
        if authentication is not None:
            pulumi.set(__self__, "authentication", authentication)
        if backup_service_enabled is not None:
            pulumi.set(__self__, "backup_service_enabled", backup_service_enabled)
        if client_connection_port is not None:
            pulumi.set(__self__, "client_connection_port", client_connection_port)
        if custom_fabric_settings is not None:
            pulumi.set(__self__, "custom_fabric_settings", custom_fabric_settings)
        if dns_name is not None:
            pulumi.set(__self__, "dns_name", dns_name)
        if dns_service_enabled is not None:
            pulumi.set(__self__, "dns_service_enabled", dns_service_enabled)
        if http_gateway_port is not None:
            pulumi.set(__self__, "http_gateway_port", http_gateway_port)
        if lb_rules is not None:
            pulumi.set(__self__, "lb_rules", lb_rules)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_types is not None:
            pulumi.set(__self__, "node_types", node_types)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if sku is not None:
            pulumi.set(__self__, "sku", sku)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if upgrade_wave is not None:
            pulumi.set(__self__, "upgrade_wave", upgrade_wave)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def authentication(self) -> Optional[pulumi.Input['ManagedClusterAuthenticationArgs']]:
        """
        Controls how connections to the cluster are authenticated. A `authentication` block as defined below.
        """
        return pulumi.get(self, "authentication")

    @authentication.setter
    def authentication(self, value: Optional[pulumi.Input['ManagedClusterAuthenticationArgs']]):
        pulumi.set(self, "authentication", value)

    @property
    @pulumi.getter(name="backupServiceEnabled")
    def backup_service_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, backup service is enabled.
        """
        return pulumi.get(self, "backup_service_enabled")

    @backup_service_enabled.setter
    def backup_service_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "backup_service_enabled", value)

    @property
    @pulumi.getter(name="clientConnectionPort")
    def client_connection_port(self) -> Optional[pulumi.Input[int]]:
        """
        Port to use when connecting to the cluster.
        """
        return pulumi.get(self, "client_connection_port")

    @client_connection_port.setter
    def client_connection_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "client_connection_port", value)

    @property
    @pulumi.getter(name="customFabricSettings")
    def custom_fabric_settings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ManagedClusterCustomFabricSettingArgs']]]]:
        """
        One or more `custom_fabric_setting` blocks as defined below.
        """
        return pulumi.get(self, "custom_fabric_settings")

    @custom_fabric_settings.setter
    def custom_fabric_settings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ManagedClusterCustomFabricSettingArgs']]]]):
        pulumi.set(self, "custom_fabric_settings", value)

    @property
    @pulumi.getter(name="dnsName")
    def dns_name(self) -> Optional[pulumi.Input[str]]:
        """
        Hostname for the cluster. If unset the cluster's name will be used..
        """
        return pulumi.get(self, "dns_name")

    @dns_name.setter
    def dns_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dns_name", value)

    @property
    @pulumi.getter(name="dnsServiceEnabled")
    def dns_service_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, DNS service is enabled.
        """
        return pulumi.get(self, "dns_service_enabled")

    @dns_service_enabled.setter
    def dns_service_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dns_service_enabled", value)

    @property
    @pulumi.getter(name="httpGatewayPort")
    def http_gateway_port(self) -> Optional[pulumi.Input[int]]:
        """
        Port that should be used by the Service Fabric Explorer to visualize applications and cluster status.
        """
        return pulumi.get(self, "http_gateway_port")

    @http_gateway_port.setter
    def http_gateway_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "http_gateway_port", value)

    @property
    @pulumi.getter(name="lbRules")
    def lb_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ManagedClusterLbRuleArgs']]]]:
        """
        One or more `lb_rule` blocks as defined below.
        """
        return pulumi.get(self, "lb_rules")

    @lb_rules.setter
    def lb_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ManagedClusterLbRuleArgs']]]]):
        pulumi.set(self, "lb_rules", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        The Azure Region where the Resource Group should exist. Changing this forces a new Resource Group to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this Resource Group. Changing this forces a new Resource Group to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="nodeTypes")
    def node_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ManagedClusterNodeTypeArgs']]]]:
        """
        One or more `node_type` blocks as defined below.
        """
        return pulumi.get(self, "node_types")

    @node_types.setter
    def node_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ManagedClusterNodeTypeArgs']]]]):
        pulumi.set(self, "node_types", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        Administrator password for the VMs that will be created as part of this cluster.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Resource Group where the Resource Group should exist. Changing this forces a new Resource Group to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter
    def sku(self) -> Optional[pulumi.Input[str]]:
        """
        SKU for this cluster. Changing this forces a new resource to be created. Default is `Basic`, allowed values are either `Basic` or `Standard`.
        """
        return pulumi.get(self, "sku")

    @sku.setter
    def sku(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sku", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags which should be assigned to the Resource Group.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="upgradeWave")
    def upgrade_wave(self) -> Optional[pulumi.Input[str]]:
        """
        Upgrade wave for the fabric runtime. Default is `Wave0`, allowed value must be one of `Wave0`, `Wave1`, or `Wave2`.
        """
        return pulumi.get(self, "upgrade_wave")

    @upgrade_wave.setter
    def upgrade_wave(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "upgrade_wave", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[str]]:
        """
        Administrator password for the VMs that will be created as part of this cluster.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username", value)


class ManagedCluster(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authentication: Optional[pulumi.Input[Union['ManagedClusterAuthenticationArgs', 'ManagedClusterAuthenticationArgsDict']]] = None,
                 backup_service_enabled: Optional[pulumi.Input[bool]] = None,
                 client_connection_port: Optional[pulumi.Input[int]] = None,
                 custom_fabric_settings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ManagedClusterCustomFabricSettingArgs', 'ManagedClusterCustomFabricSettingArgsDict']]]]] = None,
                 dns_name: Optional[pulumi.Input[str]] = None,
                 dns_service_enabled: Optional[pulumi.Input[bool]] = None,
                 http_gateway_port: Optional[pulumi.Input[int]] = None,
                 lb_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ManagedClusterLbRuleArgs', 'ManagedClusterLbRuleArgsDict']]]]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 node_types: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ManagedClusterNodeTypeArgs', 'ManagedClusterNodeTypeArgsDict']]]]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 sku: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 upgrade_wave: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Resource Group.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.servicefabric.ManagedCluster("example",
            name="example",
            resource_group_name="example",
            location="West Europe",
            http_gateway_port=4567,
            lb_rules=[{
                "backend_port": 38080,
                "frontend_port": 80,
                "probe_protocol": "http",
                "probe_request_path": "/test",
                "protocol": "tcp",
            }],
            client_connection_port=12345,
            node_types=[{
                "data_disk_size_gb": 130,
                "name": "test1",
                "primary": True,
                "application_port_range": "30000-49000",
                "ephemeral_port_range": "10000-20000",
                "vm_size": "Standard_DS1_v2",
                "vm_image_publisher": "MicrosoftWindowsServer",
                "vm_image_sku": "2019-Datacenter-with-Containers",
                "vm_image_offer": "WindowsServer",
                "vm_image_version": "latest",
                "vm_instance_count": 5,
            }])
        ```

        ## Import

        Resource Groups can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:servicefabric/managedCluster:ManagedCluster example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.ServiceFabric/managedClusters/clusterName1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ManagedClusterAuthenticationArgs', 'ManagedClusterAuthenticationArgsDict']] authentication: Controls how connections to the cluster are authenticated. A `authentication` block as defined below.
        :param pulumi.Input[bool] backup_service_enabled: If true, backup service is enabled.
        :param pulumi.Input[int] client_connection_port: Port to use when connecting to the cluster.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ManagedClusterCustomFabricSettingArgs', 'ManagedClusterCustomFabricSettingArgsDict']]]] custom_fabric_settings: One or more `custom_fabric_setting` blocks as defined below.
        :param pulumi.Input[str] dns_name: Hostname for the cluster. If unset the cluster's name will be used..
        :param pulumi.Input[bool] dns_service_enabled: If true, DNS service is enabled.
        :param pulumi.Input[int] http_gateway_port: Port that should be used by the Service Fabric Explorer to visualize applications and cluster status.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ManagedClusterLbRuleArgs', 'ManagedClusterLbRuleArgsDict']]]] lb_rules: One or more `lb_rule` blocks as defined below.
        :param pulumi.Input[str] location: The Azure Region where the Resource Group should exist. Changing this forces a new Resource Group to be created.
        :param pulumi.Input[str] name: The name which should be used for this Resource Group. Changing this forces a new Resource Group to be created.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ManagedClusterNodeTypeArgs', 'ManagedClusterNodeTypeArgsDict']]]] node_types: One or more `node_type` blocks as defined below.
        :param pulumi.Input[str] password: Administrator password for the VMs that will be created as part of this cluster.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Resource Group should exist. Changing this forces a new Resource Group to be created.
        :param pulumi.Input[str] sku: SKU for this cluster. Changing this forces a new resource to be created. Default is `Basic`, allowed values are either `Basic` or `Standard`.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags which should be assigned to the Resource Group.
        :param pulumi.Input[str] upgrade_wave: Upgrade wave for the fabric runtime. Default is `Wave0`, allowed value must be one of `Wave0`, `Wave1`, or `Wave2`.
        :param pulumi.Input[str] username: Administrator password for the VMs that will be created as part of this cluster.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ManagedClusterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Resource Group.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.servicefabric.ManagedCluster("example",
            name="example",
            resource_group_name="example",
            location="West Europe",
            http_gateway_port=4567,
            lb_rules=[{
                "backend_port": 38080,
                "frontend_port": 80,
                "probe_protocol": "http",
                "probe_request_path": "/test",
                "protocol": "tcp",
            }],
            client_connection_port=12345,
            node_types=[{
                "data_disk_size_gb": 130,
                "name": "test1",
                "primary": True,
                "application_port_range": "30000-49000",
                "ephemeral_port_range": "10000-20000",
                "vm_size": "Standard_DS1_v2",
                "vm_image_publisher": "MicrosoftWindowsServer",
                "vm_image_sku": "2019-Datacenter-with-Containers",
                "vm_image_offer": "WindowsServer",
                "vm_image_version": "latest",
                "vm_instance_count": 5,
            }])
        ```

        ## Import

        Resource Groups can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:servicefabric/managedCluster:ManagedCluster example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.ServiceFabric/managedClusters/clusterName1
        ```

        :param str resource_name: The name of the resource.
        :param ManagedClusterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ManagedClusterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authentication: Optional[pulumi.Input[Union['ManagedClusterAuthenticationArgs', 'ManagedClusterAuthenticationArgsDict']]] = None,
                 backup_service_enabled: Optional[pulumi.Input[bool]] = None,
                 client_connection_port: Optional[pulumi.Input[int]] = None,
                 custom_fabric_settings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ManagedClusterCustomFabricSettingArgs', 'ManagedClusterCustomFabricSettingArgsDict']]]]] = None,
                 dns_name: Optional[pulumi.Input[str]] = None,
                 dns_service_enabled: Optional[pulumi.Input[bool]] = None,
                 http_gateway_port: Optional[pulumi.Input[int]] = None,
                 lb_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ManagedClusterLbRuleArgs', 'ManagedClusterLbRuleArgsDict']]]]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 node_types: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ManagedClusterNodeTypeArgs', 'ManagedClusterNodeTypeArgsDict']]]]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 sku: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 upgrade_wave: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ManagedClusterArgs.__new__(ManagedClusterArgs)

            __props__.__dict__["authentication"] = authentication
            __props__.__dict__["backup_service_enabled"] = backup_service_enabled
            if client_connection_port is None and not opts.urn:
                raise TypeError("Missing required property 'client_connection_port'")
            __props__.__dict__["client_connection_port"] = client_connection_port
            __props__.__dict__["custom_fabric_settings"] = custom_fabric_settings
            __props__.__dict__["dns_name"] = dns_name
            __props__.__dict__["dns_service_enabled"] = dns_service_enabled
            if http_gateway_port is None and not opts.urn:
                raise TypeError("Missing required property 'http_gateway_port'")
            __props__.__dict__["http_gateway_port"] = http_gateway_port
            if lb_rules is None and not opts.urn:
                raise TypeError("Missing required property 'lb_rules'")
            __props__.__dict__["lb_rules"] = lb_rules
            __props__.__dict__["location"] = location
            __props__.__dict__["name"] = name
            __props__.__dict__["node_types"] = node_types
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            __props__.__dict__["sku"] = sku
            __props__.__dict__["tags"] = tags
            __props__.__dict__["upgrade_wave"] = upgrade_wave
            __props__.__dict__["username"] = username
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ManagedCluster, __self__).__init__(
            'azure:servicefabric/managedCluster:ManagedCluster',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            authentication: Optional[pulumi.Input[Union['ManagedClusterAuthenticationArgs', 'ManagedClusterAuthenticationArgsDict']]] = None,
            backup_service_enabled: Optional[pulumi.Input[bool]] = None,
            client_connection_port: Optional[pulumi.Input[int]] = None,
            custom_fabric_settings: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ManagedClusterCustomFabricSettingArgs', 'ManagedClusterCustomFabricSettingArgsDict']]]]] = None,
            dns_name: Optional[pulumi.Input[str]] = None,
            dns_service_enabled: Optional[pulumi.Input[bool]] = None,
            http_gateway_port: Optional[pulumi.Input[int]] = None,
            lb_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ManagedClusterLbRuleArgs', 'ManagedClusterLbRuleArgsDict']]]]] = None,
            location: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            node_types: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ManagedClusterNodeTypeArgs', 'ManagedClusterNodeTypeArgsDict']]]]] = None,
            password: Optional[pulumi.Input[str]] = None,
            resource_group_name: Optional[pulumi.Input[str]] = None,
            sku: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            upgrade_wave: Optional[pulumi.Input[str]] = None,
            username: Optional[pulumi.Input[str]] = None) -> 'ManagedCluster':
        """
        Get an existing ManagedCluster resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ManagedClusterAuthenticationArgs', 'ManagedClusterAuthenticationArgsDict']] authentication: Controls how connections to the cluster are authenticated. A `authentication` block as defined below.
        :param pulumi.Input[bool] backup_service_enabled: If true, backup service is enabled.
        :param pulumi.Input[int] client_connection_port: Port to use when connecting to the cluster.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ManagedClusterCustomFabricSettingArgs', 'ManagedClusterCustomFabricSettingArgsDict']]]] custom_fabric_settings: One or more `custom_fabric_setting` blocks as defined below.
        :param pulumi.Input[str] dns_name: Hostname for the cluster. If unset the cluster's name will be used..
        :param pulumi.Input[bool] dns_service_enabled: If true, DNS service is enabled.
        :param pulumi.Input[int] http_gateway_port: Port that should be used by the Service Fabric Explorer to visualize applications and cluster status.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ManagedClusterLbRuleArgs', 'ManagedClusterLbRuleArgsDict']]]] lb_rules: One or more `lb_rule` blocks as defined below.
        :param pulumi.Input[str] location: The Azure Region where the Resource Group should exist. Changing this forces a new Resource Group to be created.
        :param pulumi.Input[str] name: The name which should be used for this Resource Group. Changing this forces a new Resource Group to be created.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ManagedClusterNodeTypeArgs', 'ManagedClusterNodeTypeArgsDict']]]] node_types: One or more `node_type` blocks as defined below.
        :param pulumi.Input[str] password: Administrator password for the VMs that will be created as part of this cluster.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Resource Group should exist. Changing this forces a new Resource Group to be created.
        :param pulumi.Input[str] sku: SKU for this cluster. Changing this forces a new resource to be created. Default is `Basic`, allowed values are either `Basic` or `Standard`.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags which should be assigned to the Resource Group.
        :param pulumi.Input[str] upgrade_wave: Upgrade wave for the fabric runtime. Default is `Wave0`, allowed value must be one of `Wave0`, `Wave1`, or `Wave2`.
        :param pulumi.Input[str] username: Administrator password for the VMs that will be created as part of this cluster.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ManagedClusterState.__new__(_ManagedClusterState)

        __props__.__dict__["authentication"] = authentication
        __props__.__dict__["backup_service_enabled"] = backup_service_enabled
        __props__.__dict__["client_connection_port"] = client_connection_port
        __props__.__dict__["custom_fabric_settings"] = custom_fabric_settings
        __props__.__dict__["dns_name"] = dns_name
        __props__.__dict__["dns_service_enabled"] = dns_service_enabled
        __props__.__dict__["http_gateway_port"] = http_gateway_port
        __props__.__dict__["lb_rules"] = lb_rules
        __props__.__dict__["location"] = location
        __props__.__dict__["name"] = name
        __props__.__dict__["node_types"] = node_types
        __props__.__dict__["password"] = password
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["sku"] = sku
        __props__.__dict__["tags"] = tags
        __props__.__dict__["upgrade_wave"] = upgrade_wave
        __props__.__dict__["username"] = username
        return ManagedCluster(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def authentication(self) -> pulumi.Output[Optional['outputs.ManagedClusterAuthentication']]:
        """
        Controls how connections to the cluster are authenticated. A `authentication` block as defined below.
        """
        return pulumi.get(self, "authentication")

    @property
    @pulumi.getter(name="backupServiceEnabled")
    def backup_service_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        If true, backup service is enabled.
        """
        return pulumi.get(self, "backup_service_enabled")

    @property
    @pulumi.getter(name="clientConnectionPort")
    def client_connection_port(self) -> pulumi.Output[int]:
        """
        Port to use when connecting to the cluster.
        """
        return pulumi.get(self, "client_connection_port")

    @property
    @pulumi.getter(name="customFabricSettings")
    def custom_fabric_settings(self) -> pulumi.Output[Optional[Sequence['outputs.ManagedClusterCustomFabricSetting']]]:
        """
        One or more `custom_fabric_setting` blocks as defined below.
        """
        return pulumi.get(self, "custom_fabric_settings")

    @property
    @pulumi.getter(name="dnsName")
    def dns_name(self) -> pulumi.Output[str]:
        """
        Hostname for the cluster. If unset the cluster's name will be used..
        """
        return pulumi.get(self, "dns_name")

    @property
    @pulumi.getter(name="dnsServiceEnabled")
    def dns_service_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        If true, DNS service is enabled.
        """
        return pulumi.get(self, "dns_service_enabled")

    @property
    @pulumi.getter(name="httpGatewayPort")
    def http_gateway_port(self) -> pulumi.Output[int]:
        """
        Port that should be used by the Service Fabric Explorer to visualize applications and cluster status.
        """
        return pulumi.get(self, "http_gateway_port")

    @property
    @pulumi.getter(name="lbRules")
    def lb_rules(self) -> pulumi.Output[Sequence['outputs.ManagedClusterLbRule']]:
        """
        One or more `lb_rule` blocks as defined below.
        """
        return pulumi.get(self, "lb_rules")

    @property
    @pulumi.getter
    def location(self) -> pulumi.Output[str]:
        """
        The Azure Region where the Resource Group should exist. Changing this forces a new Resource Group to be created.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name which should be used for this Resource Group. Changing this forces a new Resource Group to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nodeTypes")
    def node_types(self) -> pulumi.Output[Optional[Sequence['outputs.ManagedClusterNodeType']]]:
        """
        One or more `node_type` blocks as defined below.
        """
        return pulumi.get(self, "node_types")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[Optional[str]]:
        """
        Administrator password for the VMs that will be created as part of this cluster.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[str]:
        """
        The name of the Resource Group where the Resource Group should exist. Changing this forces a new Resource Group to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter
    def sku(self) -> pulumi.Output[Optional[str]]:
        """
        SKU for this cluster. Changing this forces a new resource to be created. Default is `Basic`, allowed values are either `Basic` or `Standard`.
        """
        return pulumi.get(self, "sku")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A mapping of tags which should be assigned to the Resource Group.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="upgradeWave")
    def upgrade_wave(self) -> pulumi.Output[Optional[str]]:
        """
        Upgrade wave for the fabric runtime. Default is `Wave0`, allowed value must be one of `Wave0`, `Wave1`, or `Wave2`.
        """
        return pulumi.get(self, "upgrade_wave")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[Optional[str]]:
        """
        Administrator password for the VMs that will be created as part of this cluster.
        """
        return pulumi.get(self, "username")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['EndpointServicebusTopicArgs', 'EndpointServicebusTopic']

@pulumi.input_type
class EndpointServicebusTopicArgs:
    def __init__(__self__, *,
                 iothub_id: pulumi.Input[str],
                 resource_group_name: pulumi.Input[str],
                 authentication_type: Optional[pulumi.Input[str]] = None,
                 connection_string: Optional[pulumi.Input[str]] = None,
                 endpoint_uri: Optional[pulumi.Input[str]] = None,
                 entity_path: Optional[pulumi.Input[str]] = None,
                 identity_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a EndpointServicebusTopic resource.
        :param pulumi.Input[str] iothub_id: The IoTHub ID for the endpoint. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group under which the Service Bus Topic has been created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] authentication_type: Type used to authenticate against the Service Bus Topic endpoint. Possible values are `keyBased` and `identityBased`. Defaults to `keyBased`.
        :param pulumi.Input[str] connection_string: The connection string for the endpoint. This attribute can only be specified and is mandatory when `authentication_type` is `keyBased`.
        :param pulumi.Input[str] endpoint_uri: URI of the Service Bus endpoint. This attribute can only be specified and is mandatory when `authentication_type` is `identityBased`.
        :param pulumi.Input[str] entity_path: Name of the Service Bus Topic. This attribute can only be specified and is mandatory when `authentication_type` is `identityBased`.
        :param pulumi.Input[str] identity_id: ID of the User Managed Identity used to authenticate against the Service Bus Topic endpoint.
               
               > **NOTE:** `identity_id` can only be specified when `authentication_type` is `identityBased`. It must be one of the `identity_ids` of the Iot Hub. If not specified when `authentication_type` is `identityBased`, System Assigned Managed Identity of the Iot Hub will be used.
        :param pulumi.Input[str] name: The name of the endpoint. The name must be unique across endpoint types. The following names are reserved: `events`, `operationsMonitoringEvents`, `fileNotifications` and `$default`. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "iothub_id", iothub_id)
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if authentication_type is not None:
            pulumi.set(__self__, "authentication_type", authentication_type)
        if connection_string is not None:
            pulumi.set(__self__, "connection_string", connection_string)
        if endpoint_uri is not None:
            pulumi.set(__self__, "endpoint_uri", endpoint_uri)
        if entity_path is not None:
            pulumi.set(__self__, "entity_path", entity_path)
        if identity_id is not None:
            pulumi.set(__self__, "identity_id", identity_id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="iothubId")
    def iothub_id(self) -> pulumi.Input[str]:
        """
        The IoTHub ID for the endpoint. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "iothub_id")

    @iothub_id.setter
    def iothub_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "iothub_id", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[str]:
        """
        The name of the resource group under which the Service Bus Topic has been created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="authenticationType")
    def authentication_type(self) -> Optional[pulumi.Input[str]]:
        """
        Type used to authenticate against the Service Bus Topic endpoint. Possible values are `keyBased` and `identityBased`. Defaults to `keyBased`.
        """
        return pulumi.get(self, "authentication_type")

    @authentication_type.setter
    def authentication_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "authentication_type", value)

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> Optional[pulumi.Input[str]]:
        """
        The connection string for the endpoint. This attribute can only be specified and is mandatory when `authentication_type` is `keyBased`.
        """
        return pulumi.get(self, "connection_string")

    @connection_string.setter
    def connection_string(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connection_string", value)

    @property
    @pulumi.getter(name="endpointUri")
    def endpoint_uri(self) -> Optional[pulumi.Input[str]]:
        """
        URI of the Service Bus endpoint. This attribute can only be specified and is mandatory when `authentication_type` is `identityBased`.
        """
        return pulumi.get(self, "endpoint_uri")

    @endpoint_uri.setter
    def endpoint_uri(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "endpoint_uri", value)

    @property
    @pulumi.getter(name="entityPath")
    def entity_path(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the Service Bus Topic. This attribute can only be specified and is mandatory when `authentication_type` is `identityBased`.
        """
        return pulumi.get(self, "entity_path")

    @entity_path.setter
    def entity_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "entity_path", value)

    @property
    @pulumi.getter(name="identityId")
    def identity_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the User Managed Identity used to authenticate against the Service Bus Topic endpoint.

        > **NOTE:** `identity_id` can only be specified when `authentication_type` is `identityBased`. It must be one of the `identity_ids` of the Iot Hub. If not specified when `authentication_type` is `identityBased`, System Assigned Managed Identity of the Iot Hub will be used.
        """
        return pulumi.get(self, "identity_id")

    @identity_id.setter
    def identity_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "identity_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the endpoint. The name must be unique across endpoint types. The following names are reserved: `events`, `operationsMonitoringEvents`, `fileNotifications` and `$default`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _EndpointServicebusTopicState:
    def __init__(__self__, *,
                 authentication_type: Optional[pulumi.Input[str]] = None,
                 connection_string: Optional[pulumi.Input[str]] = None,
                 endpoint_uri: Optional[pulumi.Input[str]] = None,
                 entity_path: Optional[pulumi.Input[str]] = None,
                 identity_id: Optional[pulumi.Input[str]] = None,
                 iothub_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering EndpointServicebusTopic resources.
        :param pulumi.Input[str] authentication_type: Type used to authenticate against the Service Bus Topic endpoint. Possible values are `keyBased` and `identityBased`. Defaults to `keyBased`.
        :param pulumi.Input[str] connection_string: The connection string for the endpoint. This attribute can only be specified and is mandatory when `authentication_type` is `keyBased`.
        :param pulumi.Input[str] endpoint_uri: URI of the Service Bus endpoint. This attribute can only be specified and is mandatory when `authentication_type` is `identityBased`.
        :param pulumi.Input[str] entity_path: Name of the Service Bus Topic. This attribute can only be specified and is mandatory when `authentication_type` is `identityBased`.
        :param pulumi.Input[str] identity_id: ID of the User Managed Identity used to authenticate against the Service Bus Topic endpoint.
               
               > **NOTE:** `identity_id` can only be specified when `authentication_type` is `identityBased`. It must be one of the `identity_ids` of the Iot Hub. If not specified when `authentication_type` is `identityBased`, System Assigned Managed Identity of the Iot Hub will be used.
        :param pulumi.Input[str] iothub_id: The IoTHub ID for the endpoint. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the endpoint. The name must be unique across endpoint types. The following names are reserved: `events`, `operationsMonitoringEvents`, `fileNotifications` and `$default`. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group under which the Service Bus Topic has been created. Changing this forces a new resource to be created.
        """
        if authentication_type is not None:
            pulumi.set(__self__, "authentication_type", authentication_type)
        if connection_string is not None:
            pulumi.set(__self__, "connection_string", connection_string)
        if endpoint_uri is not None:
            pulumi.set(__self__, "endpoint_uri", endpoint_uri)
        if entity_path is not None:
            pulumi.set(__self__, "entity_path", entity_path)
        if identity_id is not None:
            pulumi.set(__self__, "identity_id", identity_id)
        if iothub_id is not None:
            pulumi.set(__self__, "iothub_id", iothub_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)

    @property
    @pulumi.getter(name="authenticationType")
    def authentication_type(self) -> Optional[pulumi.Input[str]]:
        """
        Type used to authenticate against the Service Bus Topic endpoint. Possible values are `keyBased` and `identityBased`. Defaults to `keyBased`.
        """
        return pulumi.get(self, "authentication_type")

    @authentication_type.setter
    def authentication_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "authentication_type", value)

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> Optional[pulumi.Input[str]]:
        """
        The connection string for the endpoint. This attribute can only be specified and is mandatory when `authentication_type` is `keyBased`.
        """
        return pulumi.get(self, "connection_string")

    @connection_string.setter
    def connection_string(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connection_string", value)

    @property
    @pulumi.getter(name="endpointUri")
    def endpoint_uri(self) -> Optional[pulumi.Input[str]]:
        """
        URI of the Service Bus endpoint. This attribute can only be specified and is mandatory when `authentication_type` is `identityBased`.
        """
        return pulumi.get(self, "endpoint_uri")

    @endpoint_uri.setter
    def endpoint_uri(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "endpoint_uri", value)

    @property
    @pulumi.getter(name="entityPath")
    def entity_path(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the Service Bus Topic. This attribute can only be specified and is mandatory when `authentication_type` is `identityBased`.
        """
        return pulumi.get(self, "entity_path")

    @entity_path.setter
    def entity_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "entity_path", value)

    @property
    @pulumi.getter(name="identityId")
    def identity_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the User Managed Identity used to authenticate against the Service Bus Topic endpoint.

        > **NOTE:** `identity_id` can only be specified when `authentication_type` is `identityBased`. It must be one of the `identity_ids` of the Iot Hub. If not specified when `authentication_type` is `identityBased`, System Assigned Managed Identity of the Iot Hub will be used.
        """
        return pulumi.get(self, "identity_id")

    @identity_id.setter
    def identity_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "identity_id", value)

    @property
    @pulumi.getter(name="iothubId")
    def iothub_id(self) -> Optional[pulumi.Input[str]]:
        """
        The IoTHub ID for the endpoint. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "iothub_id")

    @iothub_id.setter
    def iothub_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "iothub_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the endpoint. The name must be unique across endpoint types. The following names are reserved: `events`, `operationsMonitoringEvents`, `fileNotifications` and `$default`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the resource group under which the Service Bus Topic has been created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_name", value)


class EndpointServicebusTopic(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authentication_type: Optional[pulumi.Input[str]] = None,
                 connection_string: Optional[pulumi.Input[str]] = None,
                 endpoint_uri: Optional[pulumi.Input[str]] = None,
                 entity_path: Optional[pulumi.Input[str]] = None,
                 identity_id: Optional[pulumi.Input[str]] = None,
                 iothub_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages an IotHub ServiceBus Topic Endpoint

        > **NOTE:** Endpoints can be defined either directly on the `iot.IoTHub` resource, or using the `azurerm_iothub_endpoint_*` resources - but the two ways of defining the endpoints cannot be used together. If both are used against the same IoTHub, spurious changes will occur. Also, defining a `azurerm_iothub_endpoint_*` resource and another endpoint of a different type directly on the `iot.IoTHub` resource is not supported.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_namespace = azure.servicebus.Namespace("example",
            name="exampleNamespace",
            location=example.location,
            resource_group_name=example.name,
            sku="Standard")
        example_topic = azure.servicebus.Topic("example",
            name="exampleTopic",
            namespace_id=example_namespace.id)
        example_topic_authorization_rule = azure.servicebus.TopicAuthorizationRule("example",
            name="exampleRule",
            topic_id=example_topic.id,
            listen=False,
            send=True,
            manage=False)
        example_io_t_hub = azure.iot.IoTHub("example",
            name="exampleIothub",
            resource_group_name=example.name,
            location=example.location,
            sku={
                "name": "B1",
                "capacity": 1,
            },
            tags={
                "purpose": "example",
            })
        example_endpoint_servicebus_topic = azure.iot.EndpointServicebusTopic("example",
            resource_group_name=example.name,
            iothub_id=example_io_t_hub.id,
            name="example",
            connection_string=example_topic_authorization_rule.primary_connection_string)
        ```

        ## Import

        IoTHub ServiceBus Topic Endpoint can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:iot/endpointServicebusTopic:EndpointServicebusTopic servicebus_topic1 /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/mygroup1/providers/Microsoft.Devices/iotHubs/hub1/endpoints/servicebustopic_endpoint1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] authentication_type: Type used to authenticate against the Service Bus Topic endpoint. Possible values are `keyBased` and `identityBased`. Defaults to `keyBased`.
        :param pulumi.Input[str] connection_string: The connection string for the endpoint. This attribute can only be specified and is mandatory when `authentication_type` is `keyBased`.
        :param pulumi.Input[str] endpoint_uri: URI of the Service Bus endpoint. This attribute can only be specified and is mandatory when `authentication_type` is `identityBased`.
        :param pulumi.Input[str] entity_path: Name of the Service Bus Topic. This attribute can only be specified and is mandatory when `authentication_type` is `identityBased`.
        :param pulumi.Input[str] identity_id: ID of the User Managed Identity used to authenticate against the Service Bus Topic endpoint.
               
               > **NOTE:** `identity_id` can only be specified when `authentication_type` is `identityBased`. It must be one of the `identity_ids` of the Iot Hub. If not specified when `authentication_type` is `identityBased`, System Assigned Managed Identity of the Iot Hub will be used.
        :param pulumi.Input[str] iothub_id: The IoTHub ID for the endpoint. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the endpoint. The name must be unique across endpoint types. The following names are reserved: `events`, `operationsMonitoringEvents`, `fileNotifications` and `$default`. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group under which the Service Bus Topic has been created. Changing this forces a new resource to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EndpointServicebusTopicArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages an IotHub ServiceBus Topic Endpoint

        > **NOTE:** Endpoints can be defined either directly on the `iot.IoTHub` resource, or using the `azurerm_iothub_endpoint_*` resources - but the two ways of defining the endpoints cannot be used together. If both are used against the same IoTHub, spurious changes will occur. Also, defining a `azurerm_iothub_endpoint_*` resource and another endpoint of a different type directly on the `iot.IoTHub` resource is not supported.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_namespace = azure.servicebus.Namespace("example",
            name="exampleNamespace",
            location=example.location,
            resource_group_name=example.name,
            sku="Standard")
        example_topic = azure.servicebus.Topic("example",
            name="exampleTopic",
            namespace_id=example_namespace.id)
        example_topic_authorization_rule = azure.servicebus.TopicAuthorizationRule("example",
            name="exampleRule",
            topic_id=example_topic.id,
            listen=False,
            send=True,
            manage=False)
        example_io_t_hub = azure.iot.IoTHub("example",
            name="exampleIothub",
            resource_group_name=example.name,
            location=example.location,
            sku={
                "name": "B1",
                "capacity": 1,
            },
            tags={
                "purpose": "example",
            })
        example_endpoint_servicebus_topic = azure.iot.EndpointServicebusTopic("example",
            resource_group_name=example.name,
            iothub_id=example_io_t_hub.id,
            name="example",
            connection_string=example_topic_authorization_rule.primary_connection_string)
        ```

        ## Import

        IoTHub ServiceBus Topic Endpoint can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:iot/endpointServicebusTopic:EndpointServicebusTopic servicebus_topic1 /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/mygroup1/providers/Microsoft.Devices/iotHubs/hub1/endpoints/servicebustopic_endpoint1
        ```

        :param str resource_name: The name of the resource.
        :param EndpointServicebusTopicArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EndpointServicebusTopicArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authentication_type: Optional[pulumi.Input[str]] = None,
                 connection_string: Optional[pulumi.Input[str]] = None,
                 endpoint_uri: Optional[pulumi.Input[str]] = None,
                 entity_path: Optional[pulumi.Input[str]] = None,
                 identity_id: Optional[pulumi.Input[str]] = None,
                 iothub_id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EndpointServicebusTopicArgs.__new__(EndpointServicebusTopicArgs)

            __props__.__dict__["authentication_type"] = authentication_type
            __props__.__dict__["connection_string"] = None if connection_string is None else pulumi.Output.secret(connection_string)
            __props__.__dict__["endpoint_uri"] = endpoint_uri
            __props__.__dict__["entity_path"] = entity_path
            __props__.__dict__["identity_id"] = identity_id
            if iothub_id is None and not opts.urn:
                raise TypeError("Missing required property 'iothub_id'")
            __props__.__dict__["iothub_id"] = iothub_id
            __props__.__dict__["name"] = name
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["connectionString"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(EndpointServicebusTopic, __self__).__init__(
            'azure:iot/endpointServicebusTopic:EndpointServicebusTopic',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            authentication_type: Optional[pulumi.Input[str]] = None,
            connection_string: Optional[pulumi.Input[str]] = None,
            endpoint_uri: Optional[pulumi.Input[str]] = None,
            entity_path: Optional[pulumi.Input[str]] = None,
            identity_id: Optional[pulumi.Input[str]] = None,
            iothub_id: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            resource_group_name: Optional[pulumi.Input[str]] = None) -> 'EndpointServicebusTopic':
        """
        Get an existing EndpointServicebusTopic resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] authentication_type: Type used to authenticate against the Service Bus Topic endpoint. Possible values are `keyBased` and `identityBased`. Defaults to `keyBased`.
        :param pulumi.Input[str] connection_string: The connection string for the endpoint. This attribute can only be specified and is mandatory when `authentication_type` is `keyBased`.
        :param pulumi.Input[str] endpoint_uri: URI of the Service Bus endpoint. This attribute can only be specified and is mandatory when `authentication_type` is `identityBased`.
        :param pulumi.Input[str] entity_path: Name of the Service Bus Topic. This attribute can only be specified and is mandatory when `authentication_type` is `identityBased`.
        :param pulumi.Input[str] identity_id: ID of the User Managed Identity used to authenticate against the Service Bus Topic endpoint.
               
               > **NOTE:** `identity_id` can only be specified when `authentication_type` is `identityBased`. It must be one of the `identity_ids` of the Iot Hub. If not specified when `authentication_type` is `identityBased`, System Assigned Managed Identity of the Iot Hub will be used.
        :param pulumi.Input[str] iothub_id: The IoTHub ID for the endpoint. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the endpoint. The name must be unique across endpoint types. The following names are reserved: `events`, `operationsMonitoringEvents`, `fileNotifications` and `$default`. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group under which the Service Bus Topic has been created. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EndpointServicebusTopicState.__new__(_EndpointServicebusTopicState)

        __props__.__dict__["authentication_type"] = authentication_type
        __props__.__dict__["connection_string"] = connection_string
        __props__.__dict__["endpoint_uri"] = endpoint_uri
        __props__.__dict__["entity_path"] = entity_path
        __props__.__dict__["identity_id"] = identity_id
        __props__.__dict__["iothub_id"] = iothub_id
        __props__.__dict__["name"] = name
        __props__.__dict__["resource_group_name"] = resource_group_name
        return EndpointServicebusTopic(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="authenticationType")
    def authentication_type(self) -> pulumi.Output[Optional[str]]:
        """
        Type used to authenticate against the Service Bus Topic endpoint. Possible values are `keyBased` and `identityBased`. Defaults to `keyBased`.
        """
        return pulumi.get(self, "authentication_type")

    @property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> pulumi.Output[Optional[str]]:
        """
        The connection string for the endpoint. This attribute can only be specified and is mandatory when `authentication_type` is `keyBased`.
        """
        return pulumi.get(self, "connection_string")

    @property
    @pulumi.getter(name="endpointUri")
    def endpoint_uri(self) -> pulumi.Output[Optional[str]]:
        """
        URI of the Service Bus endpoint. This attribute can only be specified and is mandatory when `authentication_type` is `identityBased`.
        """
        return pulumi.get(self, "endpoint_uri")

    @property
    @pulumi.getter(name="entityPath")
    def entity_path(self) -> pulumi.Output[Optional[str]]:
        """
        Name of the Service Bus Topic. This attribute can only be specified and is mandatory when `authentication_type` is `identityBased`.
        """
        return pulumi.get(self, "entity_path")

    @property
    @pulumi.getter(name="identityId")
    def identity_id(self) -> pulumi.Output[Optional[str]]:
        """
        ID of the User Managed Identity used to authenticate against the Service Bus Topic endpoint.

        > **NOTE:** `identity_id` can only be specified when `authentication_type` is `identityBased`. It must be one of the `identity_ids` of the Iot Hub. If not specified when `authentication_type` is `identityBased`, System Assigned Managed Identity of the Iot Hub will be used.
        """
        return pulumi.get(self, "identity_id")

    @property
    @pulumi.getter(name="iothubId")
    def iothub_id(self) -> pulumi.Output[str]:
        """
        The IoTHub ID for the endpoint. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "iothub_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the endpoint. The name must be unique across endpoint types. The following names are reserved: `events`, `operationsMonitoringEvents`, `fileNotifications` and `$default`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[str]:
        """
        The name of the resource group under which the Service Bus Topic has been created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AuthorizationServerArgs', 'AuthorizationServer']

@pulumi.input_type
class AuthorizationServerArgs:
    def __init__(__self__, *,
                 api_management_name: pulumi.Input[str],
                 authorization_endpoint: pulumi.Input[str],
                 authorization_methods: pulumi.Input[Sequence[pulumi.Input[str]]],
                 client_id: pulumi.Input[str],
                 client_registration_endpoint: pulumi.Input[str],
                 display_name: pulumi.Input[str],
                 grant_types: pulumi.Input[Sequence[pulumi.Input[str]]],
                 resource_group_name: pulumi.Input[str],
                 bearer_token_sending_methods: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 client_authentication_methods: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 client_secret: Optional[pulumi.Input[str]] = None,
                 default_scope: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 resource_owner_password: Optional[pulumi.Input[str]] = None,
                 resource_owner_username: Optional[pulumi.Input[str]] = None,
                 support_state: Optional[pulumi.Input[bool]] = None,
                 token_body_parameters: Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationServerTokenBodyParameterArgs']]]] = None,
                 token_endpoint: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a AuthorizationServer resource.
        :param pulumi.Input[str] api_management_name: The name of the API Management Service in which this Authorization Server should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] authorization_endpoint: The OAUTH Authorization Endpoint.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] authorization_methods: The HTTP Verbs supported by the Authorization Endpoint. Possible values are `DELETE`, `GET`, `HEAD`, `OPTIONS`, `PATCH`, `POST`, `PUT` and `TRACE`.
               
               > **NOTE:** `GET` must always be present.
        :param pulumi.Input[str] client_id: The Client/App ID registered with this Authorization Server.
        :param pulumi.Input[str] client_registration_endpoint: The URI of page where Client/App Registration is performed for this Authorization Server.
        :param pulumi.Input[str] display_name: The user-friendly name of this Authorization Server.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] grant_types: Form of Authorization Grants required when requesting an Access Token. Possible values are `authorizationCode`, `clientCredentials`, `implicit` and `resourceOwnerPassword`.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group in which the API Management Service exists. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] bearer_token_sending_methods: The mechanism by which Access Tokens are passed to the API. Possible values are `authorizationHeader` and `query`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] client_authentication_methods: The Authentication Methods supported by the Token endpoint of this Authorization Server.. Possible values are `Basic` and `Body`.
        :param pulumi.Input[str] client_secret: The Client/App Secret registered with this Authorization Server.
        :param pulumi.Input[str] default_scope: The Default Scope used when requesting an Access Token, specified as a string containing space-delimited values.
        :param pulumi.Input[str] description: A description of the Authorization Server, which may contain HTML formatting tags.
        :param pulumi.Input[str] name: The name of this Authorization Server. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_owner_password: The password associated with the Resource Owner.
               
               > **NOTE:** This can only be specified when `grant_type` includes `resourceOwnerPassword`.
        :param pulumi.Input[str] resource_owner_username: The username associated with the Resource Owner.
               
               > **NOTE:** This can only be specified when `grant_type` includes `resourceOwnerPassword`.
        :param pulumi.Input[bool] support_state: Does this Authorization Server support State? If this is set to `true` the client may use the state parameter to raise protocol security.
        :param pulumi.Input[Sequence[pulumi.Input['AuthorizationServerTokenBodyParameterArgs']]] token_body_parameters: A `token_body_parameter` block as defined below.
        :param pulumi.Input[str] token_endpoint: The OAUTH Token Endpoint.
        """
        pulumi.set(__self__, "api_management_name", api_management_name)
        pulumi.set(__self__, "authorization_endpoint", authorization_endpoint)
        pulumi.set(__self__, "authorization_methods", authorization_methods)
        pulumi.set(__self__, "client_id", client_id)
        pulumi.set(__self__, "client_registration_endpoint", client_registration_endpoint)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "grant_types", grant_types)
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if bearer_token_sending_methods is not None:
            pulumi.set(__self__, "bearer_token_sending_methods", bearer_token_sending_methods)
        if client_authentication_methods is not None:
            pulumi.set(__self__, "client_authentication_methods", client_authentication_methods)
        if client_secret is not None:
            pulumi.set(__self__, "client_secret", client_secret)
        if default_scope is not None:
            pulumi.set(__self__, "default_scope", default_scope)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if resource_owner_password is not None:
            pulumi.set(__self__, "resource_owner_password", resource_owner_password)
        if resource_owner_username is not None:
            pulumi.set(__self__, "resource_owner_username", resource_owner_username)
        if support_state is not None:
            pulumi.set(__self__, "support_state", support_state)
        if token_body_parameters is not None:
            pulumi.set(__self__, "token_body_parameters", token_body_parameters)
        if token_endpoint is not None:
            pulumi.set(__self__, "token_endpoint", token_endpoint)

    @property
    @pulumi.getter(name="apiManagementName")
    def api_management_name(self) -> pulumi.Input[str]:
        """
        The name of the API Management Service in which this Authorization Server should be created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "api_management_name")

    @api_management_name.setter
    def api_management_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "api_management_name", value)

    @property
    @pulumi.getter(name="authorizationEndpoint")
    def authorization_endpoint(self) -> pulumi.Input[str]:
        """
        The OAUTH Authorization Endpoint.
        """
        return pulumi.get(self, "authorization_endpoint")

    @authorization_endpoint.setter
    def authorization_endpoint(self, value: pulumi.Input[str]):
        pulumi.set(self, "authorization_endpoint", value)

    @property
    @pulumi.getter(name="authorizationMethods")
    def authorization_methods(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        The HTTP Verbs supported by the Authorization Endpoint. Possible values are `DELETE`, `GET`, `HEAD`, `OPTIONS`, `PATCH`, `POST`, `PUT` and `TRACE`.

        > **NOTE:** `GET` must always be present.
        """
        return pulumi.get(self, "authorization_methods")

    @authorization_methods.setter
    def authorization_methods(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "authorization_methods", value)

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> pulumi.Input[str]:
        """
        The Client/App ID registered with this Authorization Server.
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "client_id", value)

    @property
    @pulumi.getter(name="clientRegistrationEndpoint")
    def client_registration_endpoint(self) -> pulumi.Input[str]:
        """
        The URI of page where Client/App Registration is performed for this Authorization Server.
        """
        return pulumi.get(self, "client_registration_endpoint")

    @client_registration_endpoint.setter
    def client_registration_endpoint(self, value: pulumi.Input[str]):
        pulumi.set(self, "client_registration_endpoint", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[str]:
        """
        The user-friendly name of this Authorization Server.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="grantTypes")
    def grant_types(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        Form of Authorization Grants required when requesting an Access Token. Possible values are `authorizationCode`, `clientCredentials`, `implicit` and `resourceOwnerPassword`.
        """
        return pulumi.get(self, "grant_types")

    @grant_types.setter
    def grant_types(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "grant_types", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[str]:
        """
        The name of the Resource Group in which the API Management Service exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="bearerTokenSendingMethods")
    def bearer_token_sending_methods(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The mechanism by which Access Tokens are passed to the API. Possible values are `authorizationHeader` and `query`.
        """
        return pulumi.get(self, "bearer_token_sending_methods")

    @bearer_token_sending_methods.setter
    def bearer_token_sending_methods(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "bearer_token_sending_methods", value)

    @property
    @pulumi.getter(name="clientAuthenticationMethods")
    def client_authentication_methods(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The Authentication Methods supported by the Token endpoint of this Authorization Server.. Possible values are `Basic` and `Body`.
        """
        return pulumi.get(self, "client_authentication_methods")

    @client_authentication_methods.setter
    def client_authentication_methods(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "client_authentication_methods", value)

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> Optional[pulumi.Input[str]]:
        """
        The Client/App Secret registered with this Authorization Server.
        """
        return pulumi.get(self, "client_secret")

    @client_secret.setter
    def client_secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "client_secret", value)

    @property
    @pulumi.getter(name="defaultScope")
    def default_scope(self) -> Optional[pulumi.Input[str]]:
        """
        The Default Scope used when requesting an Access Token, specified as a string containing space-delimited values.
        """
        return pulumi.get(self, "default_scope")

    @default_scope.setter
    def default_scope(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_scope", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A description of the Authorization Server, which may contain HTML formatting tags.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of this Authorization Server. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="resourceOwnerPassword")
    def resource_owner_password(self) -> Optional[pulumi.Input[str]]:
        """
        The password associated with the Resource Owner.

        > **NOTE:** This can only be specified when `grant_type` includes `resourceOwnerPassword`.
        """
        return pulumi.get(self, "resource_owner_password")

    @resource_owner_password.setter
    def resource_owner_password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_owner_password", value)

    @property
    @pulumi.getter(name="resourceOwnerUsername")
    def resource_owner_username(self) -> Optional[pulumi.Input[str]]:
        """
        The username associated with the Resource Owner.

        > **NOTE:** This can only be specified when `grant_type` includes `resourceOwnerPassword`.
        """
        return pulumi.get(self, "resource_owner_username")

    @resource_owner_username.setter
    def resource_owner_username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_owner_username", value)

    @property
    @pulumi.getter(name="supportState")
    def support_state(self) -> Optional[pulumi.Input[bool]]:
        """
        Does this Authorization Server support State? If this is set to `true` the client may use the state parameter to raise protocol security.
        """
        return pulumi.get(self, "support_state")

    @support_state.setter
    def support_state(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "support_state", value)

    @property
    @pulumi.getter(name="tokenBodyParameters")
    def token_body_parameters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationServerTokenBodyParameterArgs']]]]:
        """
        A `token_body_parameter` block as defined below.
        """
        return pulumi.get(self, "token_body_parameters")

    @token_body_parameters.setter
    def token_body_parameters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationServerTokenBodyParameterArgs']]]]):
        pulumi.set(self, "token_body_parameters", value)

    @property
    @pulumi.getter(name="tokenEndpoint")
    def token_endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        The OAUTH Token Endpoint.
        """
        return pulumi.get(self, "token_endpoint")

    @token_endpoint.setter
    def token_endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "token_endpoint", value)


@pulumi.input_type
class _AuthorizationServerState:
    def __init__(__self__, *,
                 api_management_name: Optional[pulumi.Input[str]] = None,
                 authorization_endpoint: Optional[pulumi.Input[str]] = None,
                 authorization_methods: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 bearer_token_sending_methods: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 client_authentication_methods: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 client_id: Optional[pulumi.Input[str]] = None,
                 client_registration_endpoint: Optional[pulumi.Input[str]] = None,
                 client_secret: Optional[pulumi.Input[str]] = None,
                 default_scope: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 grant_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 resource_owner_password: Optional[pulumi.Input[str]] = None,
                 resource_owner_username: Optional[pulumi.Input[str]] = None,
                 support_state: Optional[pulumi.Input[bool]] = None,
                 token_body_parameters: Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationServerTokenBodyParameterArgs']]]] = None,
                 token_endpoint: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AuthorizationServer resources.
        :param pulumi.Input[str] api_management_name: The name of the API Management Service in which this Authorization Server should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] authorization_endpoint: The OAUTH Authorization Endpoint.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] authorization_methods: The HTTP Verbs supported by the Authorization Endpoint. Possible values are `DELETE`, `GET`, `HEAD`, `OPTIONS`, `PATCH`, `POST`, `PUT` and `TRACE`.
               
               > **NOTE:** `GET` must always be present.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] bearer_token_sending_methods: The mechanism by which Access Tokens are passed to the API. Possible values are `authorizationHeader` and `query`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] client_authentication_methods: The Authentication Methods supported by the Token endpoint of this Authorization Server.. Possible values are `Basic` and `Body`.
        :param pulumi.Input[str] client_id: The Client/App ID registered with this Authorization Server.
        :param pulumi.Input[str] client_registration_endpoint: The URI of page where Client/App Registration is performed for this Authorization Server.
        :param pulumi.Input[str] client_secret: The Client/App Secret registered with this Authorization Server.
        :param pulumi.Input[str] default_scope: The Default Scope used when requesting an Access Token, specified as a string containing space-delimited values.
        :param pulumi.Input[str] description: A description of the Authorization Server, which may contain HTML formatting tags.
        :param pulumi.Input[str] display_name: The user-friendly name of this Authorization Server.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] grant_types: Form of Authorization Grants required when requesting an Access Token. Possible values are `authorizationCode`, `clientCredentials`, `implicit` and `resourceOwnerPassword`.
        :param pulumi.Input[str] name: The name of this Authorization Server. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group in which the API Management Service exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_owner_password: The password associated with the Resource Owner.
               
               > **NOTE:** This can only be specified when `grant_type` includes `resourceOwnerPassword`.
        :param pulumi.Input[str] resource_owner_username: The username associated with the Resource Owner.
               
               > **NOTE:** This can only be specified when `grant_type` includes `resourceOwnerPassword`.
        :param pulumi.Input[bool] support_state: Does this Authorization Server support State? If this is set to `true` the client may use the state parameter to raise protocol security.
        :param pulumi.Input[Sequence[pulumi.Input['AuthorizationServerTokenBodyParameterArgs']]] token_body_parameters: A `token_body_parameter` block as defined below.
        :param pulumi.Input[str] token_endpoint: The OAUTH Token Endpoint.
        """
        if api_management_name is not None:
            pulumi.set(__self__, "api_management_name", api_management_name)
        if authorization_endpoint is not None:
            pulumi.set(__self__, "authorization_endpoint", authorization_endpoint)
        if authorization_methods is not None:
            pulumi.set(__self__, "authorization_methods", authorization_methods)
        if bearer_token_sending_methods is not None:
            pulumi.set(__self__, "bearer_token_sending_methods", bearer_token_sending_methods)
        if client_authentication_methods is not None:
            pulumi.set(__self__, "client_authentication_methods", client_authentication_methods)
        if client_id is not None:
            pulumi.set(__self__, "client_id", client_id)
        if client_registration_endpoint is not None:
            pulumi.set(__self__, "client_registration_endpoint", client_registration_endpoint)
        if client_secret is not None:
            pulumi.set(__self__, "client_secret", client_secret)
        if default_scope is not None:
            pulumi.set(__self__, "default_scope", default_scope)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if grant_types is not None:
            pulumi.set(__self__, "grant_types", grant_types)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if resource_owner_password is not None:
            pulumi.set(__self__, "resource_owner_password", resource_owner_password)
        if resource_owner_username is not None:
            pulumi.set(__self__, "resource_owner_username", resource_owner_username)
        if support_state is not None:
            pulumi.set(__self__, "support_state", support_state)
        if token_body_parameters is not None:
            pulumi.set(__self__, "token_body_parameters", token_body_parameters)
        if token_endpoint is not None:
            pulumi.set(__self__, "token_endpoint", token_endpoint)

    @property
    @pulumi.getter(name="apiManagementName")
    def api_management_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the API Management Service in which this Authorization Server should be created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "api_management_name")

    @api_management_name.setter
    def api_management_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "api_management_name", value)

    @property
    @pulumi.getter(name="authorizationEndpoint")
    def authorization_endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        The OAUTH Authorization Endpoint.
        """
        return pulumi.get(self, "authorization_endpoint")

    @authorization_endpoint.setter
    def authorization_endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "authorization_endpoint", value)

    @property
    @pulumi.getter(name="authorizationMethods")
    def authorization_methods(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The HTTP Verbs supported by the Authorization Endpoint. Possible values are `DELETE`, `GET`, `HEAD`, `OPTIONS`, `PATCH`, `POST`, `PUT` and `TRACE`.

        > **NOTE:** `GET` must always be present.
        """
        return pulumi.get(self, "authorization_methods")

    @authorization_methods.setter
    def authorization_methods(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "authorization_methods", value)

    @property
    @pulumi.getter(name="bearerTokenSendingMethods")
    def bearer_token_sending_methods(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The mechanism by which Access Tokens are passed to the API. Possible values are `authorizationHeader` and `query`.
        """
        return pulumi.get(self, "bearer_token_sending_methods")

    @bearer_token_sending_methods.setter
    def bearer_token_sending_methods(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "bearer_token_sending_methods", value)

    @property
    @pulumi.getter(name="clientAuthenticationMethods")
    def client_authentication_methods(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The Authentication Methods supported by the Token endpoint of this Authorization Server.. Possible values are `Basic` and `Body`.
        """
        return pulumi.get(self, "client_authentication_methods")

    @client_authentication_methods.setter
    def client_authentication_methods(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "client_authentication_methods", value)

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Client/App ID registered with this Authorization Server.
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "client_id", value)

    @property
    @pulumi.getter(name="clientRegistrationEndpoint")
    def client_registration_endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        The URI of page where Client/App Registration is performed for this Authorization Server.
        """
        return pulumi.get(self, "client_registration_endpoint")

    @client_registration_endpoint.setter
    def client_registration_endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "client_registration_endpoint", value)

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> Optional[pulumi.Input[str]]:
        """
        The Client/App Secret registered with this Authorization Server.
        """
        return pulumi.get(self, "client_secret")

    @client_secret.setter
    def client_secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "client_secret", value)

    @property
    @pulumi.getter(name="defaultScope")
    def default_scope(self) -> Optional[pulumi.Input[str]]:
        """
        The Default Scope used when requesting an Access Token, specified as a string containing space-delimited values.
        """
        return pulumi.get(self, "default_scope")

    @default_scope.setter
    def default_scope(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "default_scope", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A description of the Authorization Server, which may contain HTML formatting tags.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        The user-friendly name of this Authorization Server.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="grantTypes")
    def grant_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Form of Authorization Grants required when requesting an Access Token. Possible values are `authorizationCode`, `clientCredentials`, `implicit` and `resourceOwnerPassword`.
        """
        return pulumi.get(self, "grant_types")

    @grant_types.setter
    def grant_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "grant_types", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of this Authorization Server. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Resource Group in which the API Management Service exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="resourceOwnerPassword")
    def resource_owner_password(self) -> Optional[pulumi.Input[str]]:
        """
        The password associated with the Resource Owner.

        > **NOTE:** This can only be specified when `grant_type` includes `resourceOwnerPassword`.
        """
        return pulumi.get(self, "resource_owner_password")

    @resource_owner_password.setter
    def resource_owner_password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_owner_password", value)

    @property
    @pulumi.getter(name="resourceOwnerUsername")
    def resource_owner_username(self) -> Optional[pulumi.Input[str]]:
        """
        The username associated with the Resource Owner.

        > **NOTE:** This can only be specified when `grant_type` includes `resourceOwnerPassword`.
        """
        return pulumi.get(self, "resource_owner_username")

    @resource_owner_username.setter
    def resource_owner_username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_owner_username", value)

    @property
    @pulumi.getter(name="supportState")
    def support_state(self) -> Optional[pulumi.Input[bool]]:
        """
        Does this Authorization Server support State? If this is set to `true` the client may use the state parameter to raise protocol security.
        """
        return pulumi.get(self, "support_state")

    @support_state.setter
    def support_state(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "support_state", value)

    @property
    @pulumi.getter(name="tokenBodyParameters")
    def token_body_parameters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationServerTokenBodyParameterArgs']]]]:
        """
        A `token_body_parameter` block as defined below.
        """
        return pulumi.get(self, "token_body_parameters")

    @token_body_parameters.setter
    def token_body_parameters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AuthorizationServerTokenBodyParameterArgs']]]]):
        pulumi.set(self, "token_body_parameters", value)

    @property
    @pulumi.getter(name="tokenEndpoint")
    def token_endpoint(self) -> Optional[pulumi.Input[str]]:
        """
        The OAUTH Token Endpoint.
        """
        return pulumi.get(self, "token_endpoint")

    @token_endpoint.setter
    def token_endpoint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "token_endpoint", value)


class AuthorizationServer(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_management_name: Optional[pulumi.Input[str]] = None,
                 authorization_endpoint: Optional[pulumi.Input[str]] = None,
                 authorization_methods: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 bearer_token_sending_methods: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 client_authentication_methods: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 client_id: Optional[pulumi.Input[str]] = None,
                 client_registration_endpoint: Optional[pulumi.Input[str]] = None,
                 client_secret: Optional[pulumi.Input[str]] = None,
                 default_scope: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 grant_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 resource_owner_password: Optional[pulumi.Input[str]] = None,
                 resource_owner_username: Optional[pulumi.Input[str]] = None,
                 support_state: Optional[pulumi.Input[bool]] = None,
                 token_body_parameters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AuthorizationServerTokenBodyParameterArgs', 'AuthorizationServerTokenBodyParameterArgsDict']]]]] = None,
                 token_endpoint: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages an Authorization Server within an API Management Service.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.apimanagement.get_service(name="search-api",
            resource_group_name="search-service")
        example_authorization_server = azure.apimanagement.AuthorizationServer("example",
            name="test-server",
            api_management_name=example.name,
            resource_group_name=example.resource_group_name,
            display_name="Test Server",
            authorization_endpoint="https://example.mydomain.com/client/authorize",
            client_id="42424242-4242-4242-4242-424242424242",
            client_registration_endpoint="https://example.mydomain.com/client/register",
            grant_types=["authorizationCode"],
            authorization_methods=["GET"])
        ```

        ## Import

        API Management Authorization Servers can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:apimanagement/authorizationServer:AuthorizationServer example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.ApiManagement/service/service1/authorizationServers/server1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] api_management_name: The name of the API Management Service in which this Authorization Server should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] authorization_endpoint: The OAUTH Authorization Endpoint.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] authorization_methods: The HTTP Verbs supported by the Authorization Endpoint. Possible values are `DELETE`, `GET`, `HEAD`, `OPTIONS`, `PATCH`, `POST`, `PUT` and `TRACE`.
               
               > **NOTE:** `GET` must always be present.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] bearer_token_sending_methods: The mechanism by which Access Tokens are passed to the API. Possible values are `authorizationHeader` and `query`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] client_authentication_methods: The Authentication Methods supported by the Token endpoint of this Authorization Server.. Possible values are `Basic` and `Body`.
        :param pulumi.Input[str] client_id: The Client/App ID registered with this Authorization Server.
        :param pulumi.Input[str] client_registration_endpoint: The URI of page where Client/App Registration is performed for this Authorization Server.
        :param pulumi.Input[str] client_secret: The Client/App Secret registered with this Authorization Server.
        :param pulumi.Input[str] default_scope: The Default Scope used when requesting an Access Token, specified as a string containing space-delimited values.
        :param pulumi.Input[str] description: A description of the Authorization Server, which may contain HTML formatting tags.
        :param pulumi.Input[str] display_name: The user-friendly name of this Authorization Server.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] grant_types: Form of Authorization Grants required when requesting an Access Token. Possible values are `authorizationCode`, `clientCredentials`, `implicit` and `resourceOwnerPassword`.
        :param pulumi.Input[str] name: The name of this Authorization Server. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group in which the API Management Service exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_owner_password: The password associated with the Resource Owner.
               
               > **NOTE:** This can only be specified when `grant_type` includes `resourceOwnerPassword`.
        :param pulumi.Input[str] resource_owner_username: The username associated with the Resource Owner.
               
               > **NOTE:** This can only be specified when `grant_type` includes `resourceOwnerPassword`.
        :param pulumi.Input[bool] support_state: Does this Authorization Server support State? If this is set to `true` the client may use the state parameter to raise protocol security.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AuthorizationServerTokenBodyParameterArgs', 'AuthorizationServerTokenBodyParameterArgsDict']]]] token_body_parameters: A `token_body_parameter` block as defined below.
        :param pulumi.Input[str] token_endpoint: The OAUTH Token Endpoint.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AuthorizationServerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages an Authorization Server within an API Management Service.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.apimanagement.get_service(name="search-api",
            resource_group_name="search-service")
        example_authorization_server = azure.apimanagement.AuthorizationServer("example",
            name="test-server",
            api_management_name=example.name,
            resource_group_name=example.resource_group_name,
            display_name="Test Server",
            authorization_endpoint="https://example.mydomain.com/client/authorize",
            client_id="42424242-4242-4242-4242-424242424242",
            client_registration_endpoint="https://example.mydomain.com/client/register",
            grant_types=["authorizationCode"],
            authorization_methods=["GET"])
        ```

        ## Import

        API Management Authorization Servers can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:apimanagement/authorizationServer:AuthorizationServer example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.ApiManagement/service/service1/authorizationServers/server1
        ```

        :param str resource_name: The name of the resource.
        :param AuthorizationServerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AuthorizationServerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_management_name: Optional[pulumi.Input[str]] = None,
                 authorization_endpoint: Optional[pulumi.Input[str]] = None,
                 authorization_methods: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 bearer_token_sending_methods: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 client_authentication_methods: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 client_id: Optional[pulumi.Input[str]] = None,
                 client_registration_endpoint: Optional[pulumi.Input[str]] = None,
                 client_secret: Optional[pulumi.Input[str]] = None,
                 default_scope: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 grant_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 resource_owner_password: Optional[pulumi.Input[str]] = None,
                 resource_owner_username: Optional[pulumi.Input[str]] = None,
                 support_state: Optional[pulumi.Input[bool]] = None,
                 token_body_parameters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AuthorizationServerTokenBodyParameterArgs', 'AuthorizationServerTokenBodyParameterArgsDict']]]]] = None,
                 token_endpoint: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AuthorizationServerArgs.__new__(AuthorizationServerArgs)

            if api_management_name is None and not opts.urn:
                raise TypeError("Missing required property 'api_management_name'")
            __props__.__dict__["api_management_name"] = api_management_name
            if authorization_endpoint is None and not opts.urn:
                raise TypeError("Missing required property 'authorization_endpoint'")
            __props__.__dict__["authorization_endpoint"] = authorization_endpoint
            if authorization_methods is None and not opts.urn:
                raise TypeError("Missing required property 'authorization_methods'")
            __props__.__dict__["authorization_methods"] = authorization_methods
            __props__.__dict__["bearer_token_sending_methods"] = bearer_token_sending_methods
            __props__.__dict__["client_authentication_methods"] = client_authentication_methods
            if client_id is None and not opts.urn:
                raise TypeError("Missing required property 'client_id'")
            __props__.__dict__["client_id"] = client_id
            if client_registration_endpoint is None and not opts.urn:
                raise TypeError("Missing required property 'client_registration_endpoint'")
            __props__.__dict__["client_registration_endpoint"] = client_registration_endpoint
            __props__.__dict__["client_secret"] = None if client_secret is None else pulumi.Output.secret(client_secret)
            __props__.__dict__["default_scope"] = default_scope
            __props__.__dict__["description"] = description
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            if grant_types is None and not opts.urn:
                raise TypeError("Missing required property 'grant_types'")
            __props__.__dict__["grant_types"] = grant_types
            __props__.__dict__["name"] = name
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            __props__.__dict__["resource_owner_password"] = None if resource_owner_password is None else pulumi.Output.secret(resource_owner_password)
            __props__.__dict__["resource_owner_username"] = resource_owner_username
            __props__.__dict__["support_state"] = support_state
            __props__.__dict__["token_body_parameters"] = token_body_parameters
            __props__.__dict__["token_endpoint"] = token_endpoint
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["clientSecret", "resourceOwnerPassword"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(AuthorizationServer, __self__).__init__(
            'azure:apimanagement/authorizationServer:AuthorizationServer',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            api_management_name: Optional[pulumi.Input[str]] = None,
            authorization_endpoint: Optional[pulumi.Input[str]] = None,
            authorization_methods: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            bearer_token_sending_methods: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            client_authentication_methods: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            client_id: Optional[pulumi.Input[str]] = None,
            client_registration_endpoint: Optional[pulumi.Input[str]] = None,
            client_secret: Optional[pulumi.Input[str]] = None,
            default_scope: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            grant_types: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            resource_group_name: Optional[pulumi.Input[str]] = None,
            resource_owner_password: Optional[pulumi.Input[str]] = None,
            resource_owner_username: Optional[pulumi.Input[str]] = None,
            support_state: Optional[pulumi.Input[bool]] = None,
            token_body_parameters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AuthorizationServerTokenBodyParameterArgs', 'AuthorizationServerTokenBodyParameterArgsDict']]]]] = None,
            token_endpoint: Optional[pulumi.Input[str]] = None) -> 'AuthorizationServer':
        """
        Get an existing AuthorizationServer resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] api_management_name: The name of the API Management Service in which this Authorization Server should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] authorization_endpoint: The OAUTH Authorization Endpoint.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] authorization_methods: The HTTP Verbs supported by the Authorization Endpoint. Possible values are `DELETE`, `GET`, `HEAD`, `OPTIONS`, `PATCH`, `POST`, `PUT` and `TRACE`.
               
               > **NOTE:** `GET` must always be present.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] bearer_token_sending_methods: The mechanism by which Access Tokens are passed to the API. Possible values are `authorizationHeader` and `query`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] client_authentication_methods: The Authentication Methods supported by the Token endpoint of this Authorization Server.. Possible values are `Basic` and `Body`.
        :param pulumi.Input[str] client_id: The Client/App ID registered with this Authorization Server.
        :param pulumi.Input[str] client_registration_endpoint: The URI of page where Client/App Registration is performed for this Authorization Server.
        :param pulumi.Input[str] client_secret: The Client/App Secret registered with this Authorization Server.
        :param pulumi.Input[str] default_scope: The Default Scope used when requesting an Access Token, specified as a string containing space-delimited values.
        :param pulumi.Input[str] description: A description of the Authorization Server, which may contain HTML formatting tags.
        :param pulumi.Input[str] display_name: The user-friendly name of this Authorization Server.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] grant_types: Form of Authorization Grants required when requesting an Access Token. Possible values are `authorizationCode`, `clientCredentials`, `implicit` and `resourceOwnerPassword`.
        :param pulumi.Input[str] name: The name of this Authorization Server. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group in which the API Management Service exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_owner_password: The password associated with the Resource Owner.
               
               > **NOTE:** This can only be specified when `grant_type` includes `resourceOwnerPassword`.
        :param pulumi.Input[str] resource_owner_username: The username associated with the Resource Owner.
               
               > **NOTE:** This can only be specified when `grant_type` includes `resourceOwnerPassword`.
        :param pulumi.Input[bool] support_state: Does this Authorization Server support State? If this is set to `true` the client may use the state parameter to raise protocol security.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AuthorizationServerTokenBodyParameterArgs', 'AuthorizationServerTokenBodyParameterArgsDict']]]] token_body_parameters: A `token_body_parameter` block as defined below.
        :param pulumi.Input[str] token_endpoint: The OAUTH Token Endpoint.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AuthorizationServerState.__new__(_AuthorizationServerState)

        __props__.__dict__["api_management_name"] = api_management_name
        __props__.__dict__["authorization_endpoint"] = authorization_endpoint
        __props__.__dict__["authorization_methods"] = authorization_methods
        __props__.__dict__["bearer_token_sending_methods"] = bearer_token_sending_methods
        __props__.__dict__["client_authentication_methods"] = client_authentication_methods
        __props__.__dict__["client_id"] = client_id
        __props__.__dict__["client_registration_endpoint"] = client_registration_endpoint
        __props__.__dict__["client_secret"] = client_secret
        __props__.__dict__["default_scope"] = default_scope
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["grant_types"] = grant_types
        __props__.__dict__["name"] = name
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["resource_owner_password"] = resource_owner_password
        __props__.__dict__["resource_owner_username"] = resource_owner_username
        __props__.__dict__["support_state"] = support_state
        __props__.__dict__["token_body_parameters"] = token_body_parameters
        __props__.__dict__["token_endpoint"] = token_endpoint
        return AuthorizationServer(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="apiManagementName")
    def api_management_name(self) -> pulumi.Output[str]:
        """
        The name of the API Management Service in which this Authorization Server should be created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "api_management_name")

    @property
    @pulumi.getter(name="authorizationEndpoint")
    def authorization_endpoint(self) -> pulumi.Output[str]:
        """
        The OAUTH Authorization Endpoint.
        """
        return pulumi.get(self, "authorization_endpoint")

    @property
    @pulumi.getter(name="authorizationMethods")
    def authorization_methods(self) -> pulumi.Output[Sequence[str]]:
        """
        The HTTP Verbs supported by the Authorization Endpoint. Possible values are `DELETE`, `GET`, `HEAD`, `OPTIONS`, `PATCH`, `POST`, `PUT` and `TRACE`.

        > **NOTE:** `GET` must always be present.
        """
        return pulumi.get(self, "authorization_methods")

    @property
    @pulumi.getter(name="bearerTokenSendingMethods")
    def bearer_token_sending_methods(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The mechanism by which Access Tokens are passed to the API. Possible values are `authorizationHeader` and `query`.
        """
        return pulumi.get(self, "bearer_token_sending_methods")

    @property
    @pulumi.getter(name="clientAuthenticationMethods")
    def client_authentication_methods(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The Authentication Methods supported by the Token endpoint of this Authorization Server.. Possible values are `Basic` and `Body`.
        """
        return pulumi.get(self, "client_authentication_methods")

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> pulumi.Output[str]:
        """
        The Client/App ID registered with this Authorization Server.
        """
        return pulumi.get(self, "client_id")

    @property
    @pulumi.getter(name="clientRegistrationEndpoint")
    def client_registration_endpoint(self) -> pulumi.Output[str]:
        """
        The URI of page where Client/App Registration is performed for this Authorization Server.
        """
        return pulumi.get(self, "client_registration_endpoint")

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> pulumi.Output[Optional[str]]:
        """
        The Client/App Secret registered with this Authorization Server.
        """
        return pulumi.get(self, "client_secret")

    @property
    @pulumi.getter(name="defaultScope")
    def default_scope(self) -> pulumi.Output[Optional[str]]:
        """
        The Default Scope used when requesting an Access Token, specified as a string containing space-delimited values.
        """
        return pulumi.get(self, "default_scope")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        A description of the Authorization Server, which may contain HTML formatting tags.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        The user-friendly name of this Authorization Server.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="grantTypes")
    def grant_types(self) -> pulumi.Output[Sequence[str]]:
        """
        Form of Authorization Grants required when requesting an Access Token. Possible values are `authorizationCode`, `clientCredentials`, `implicit` and `resourceOwnerPassword`.
        """
        return pulumi.get(self, "grant_types")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of this Authorization Server. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[str]:
        """
        The name of the Resource Group in which the API Management Service exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter(name="resourceOwnerPassword")
    def resource_owner_password(self) -> pulumi.Output[Optional[str]]:
        """
        The password associated with the Resource Owner.

        > **NOTE:** This can only be specified when `grant_type` includes `resourceOwnerPassword`.
        """
        return pulumi.get(self, "resource_owner_password")

    @property
    @pulumi.getter(name="resourceOwnerUsername")
    def resource_owner_username(self) -> pulumi.Output[Optional[str]]:
        """
        The username associated with the Resource Owner.

        > **NOTE:** This can only be specified when `grant_type` includes `resourceOwnerPassword`.
        """
        return pulumi.get(self, "resource_owner_username")

    @property
    @pulumi.getter(name="supportState")
    def support_state(self) -> pulumi.Output[Optional[bool]]:
        """
        Does this Authorization Server support State? If this is set to `true` the client may use the state parameter to raise protocol security.
        """
        return pulumi.get(self, "support_state")

    @property
    @pulumi.getter(name="tokenBodyParameters")
    def token_body_parameters(self) -> pulumi.Output[Optional[Sequence['outputs.AuthorizationServerTokenBodyParameter']]]:
        """
        A `token_body_parameter` block as defined below.
        """
        return pulumi.get(self, "token_body_parameters")

    @property
    @pulumi.getter(name="tokenEndpoint")
    def token_endpoint(self) -> pulumi.Output[Optional[str]]:
        """
        The OAUTH Token Endpoint.
        """
        return pulumi.get(self, "token_endpoint")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetVirtualHubRouteTableResult',
    'AwaitableGetVirtualHubRouteTableResult',
    'get_virtual_hub_route_table',
    'get_virtual_hub_route_table_output',
]

@pulumi.output_type
class GetVirtualHubRouteTableResult:
    """
    A collection of values returned by getVirtualHubRouteTable.
    """
    def __init__(__self__, id=None, labels=None, name=None, resource_group_name=None, routes=None, virtual_hub_id=None, virtual_hub_name=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if labels and not isinstance(labels, list):
            raise TypeError("Expected argument 'labels' to be a list")
        pulumi.set(__self__, "labels", labels)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if routes and not isinstance(routes, list):
            raise TypeError("Expected argument 'routes' to be a list")
        pulumi.set(__self__, "routes", routes)
        if virtual_hub_id and not isinstance(virtual_hub_id, str):
            raise TypeError("Expected argument 'virtual_hub_id' to be a str")
        pulumi.set(__self__, "virtual_hub_id", virtual_hub_id)
        if virtual_hub_name and not isinstance(virtual_hub_name, str):
            raise TypeError("Expected argument 'virtual_hub_name' to be a str")
        pulumi.set(__self__, "virtual_hub_name", virtual_hub_name)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def labels(self) -> Sequence[str]:
        """
        List of labels associated with this route table.
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name which is used for this route.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> str:
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter
    def routes(self) -> Sequence['outputs.GetVirtualHubRouteTableRouteResult']:
        """
        A `route` block as defined below.
        """
        return pulumi.get(self, "routes")

    @property
    @pulumi.getter(name="virtualHubId")
    def virtual_hub_id(self) -> str:
        """
        The ID of the Virtual Hub within which this route table is created
        """
        return pulumi.get(self, "virtual_hub_id")

    @property
    @pulumi.getter(name="virtualHubName")
    def virtual_hub_name(self) -> str:
        return pulumi.get(self, "virtual_hub_name")


class AwaitableGetVirtualHubRouteTableResult(GetVirtualHubRouteTableResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVirtualHubRouteTableResult(
            id=self.id,
            labels=self.labels,
            name=self.name,
            resource_group_name=self.resource_group_name,
            routes=self.routes,
            virtual_hub_id=self.virtual_hub_id,
            virtual_hub_name=self.virtual_hub_name)


def get_virtual_hub_route_table(name: Optional[str] = None,
                                resource_group_name: Optional[str] = None,
                                virtual_hub_name: Optional[str] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVirtualHubRouteTableResult:
    """
    Uses this data source to access information about an existing Virtual Hub Route Table.

    ## Virtual Hub Route Table Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.network.get_virtual_hub_route_table(name="example-hub-route-table",
        resource_group_name="example-resources",
        virtual_hub_name="example-hub-name")
    pulumi.export("virtualHubRouteTableId", example.id)
    ```


    :param str name: The name of the Virtual Hub Route Table.
    :param str resource_group_name: The Name of the Resource Group where the Virtual Hub Route Table exists.
    :param str virtual_hub_name: The name which should be used for Virtual Hub Route Table.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    __args__['virtualHubName'] = virtual_hub_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:network/getVirtualHubRouteTable:getVirtualHubRouteTable', __args__, opts=opts, typ=GetVirtualHubRouteTableResult).value

    return AwaitableGetVirtualHubRouteTableResult(
        id=pulumi.get(__ret__, 'id'),
        labels=pulumi.get(__ret__, 'labels'),
        name=pulumi.get(__ret__, 'name'),
        resource_group_name=pulumi.get(__ret__, 'resource_group_name'),
        routes=pulumi.get(__ret__, 'routes'),
        virtual_hub_id=pulumi.get(__ret__, 'virtual_hub_id'),
        virtual_hub_name=pulumi.get(__ret__, 'virtual_hub_name'))
def get_virtual_hub_route_table_output(name: Optional[pulumi.Input[str]] = None,
                                       resource_group_name: Optional[pulumi.Input[str]] = None,
                                       virtual_hub_name: Optional[pulumi.Input[str]] = None,
                                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetVirtualHubRouteTableResult]:
    """
    Uses this data source to access information about an existing Virtual Hub Route Table.

    ## Virtual Hub Route Table Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.network.get_virtual_hub_route_table(name="example-hub-route-table",
        resource_group_name="example-resources",
        virtual_hub_name="example-hub-name")
    pulumi.export("virtualHubRouteTableId", example.id)
    ```


    :param str name: The name of the Virtual Hub Route Table.
    :param str resource_group_name: The Name of the Resource Group where the Virtual Hub Route Table exists.
    :param str virtual_hub_name: The name which should be used for Virtual Hub Route Table.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    __args__['virtualHubName'] = virtual_hub_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:network/getVirtualHubRouteTable:getVirtualHubRouteTable', __args__, opts=opts, typ=GetVirtualHubRouteTableResult)
    return __ret__.apply(lambda __response__: GetVirtualHubRouteTableResult(
        id=pulumi.get(__response__, 'id'),
        labels=pulumi.get(__response__, 'labels'),
        name=pulumi.get(__response__, 'name'),
        resource_group_name=pulumi.get(__response__, 'resource_group_name'),
        routes=pulumi.get(__response__, 'routes'),
        virtual_hub_id=pulumi.get(__response__, 'virtual_hub_id'),
        virtual_hub_name=pulumi.get(__response__, 'virtual_hub_name')))
